import * as React from 'react';
import * as zod from 'zod';
import { IFrameWindow } from '@crossmint/client-sdk-window';

declare function useSignerIFrameWindow(environment: string, url?: string): React.MutableRefObject<IFrameWindow<{
    readonly "response:start-onboarding": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodIntersection<zod.ZodObject<{
        status: zod.ZodLiteral<"success">;
    }, "strip", zod.ZodTypeAny, {
        status: "success";
    }, {
        status: "success";
    }>, zod.ZodUnion<[zod.ZodObject<{
        signerStatus: zod.ZodEnum<["ready"]>;
        publicKeys: zod.ZodRecord<zod.ZodEnum<["secp256k1", "ed25519"]>, zod.ZodObject<Omit<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "keyType">, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }, "strip", zod.ZodTypeAny, {
        signerStatus: "ready";
        publicKeys: Partial<Record<"secp256k1" | "ed25519", {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }, {
        signerStatus: "ready";
        publicKeys: Partial<Record<"secp256k1" | "ed25519", {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }>, zod.ZodObject<{
        signerStatus: zod.ZodEnum<["new-device"]>;
    }, "strip", zod.ZodTypeAny, {
        signerStatus: "new-device";
    }, {
        signerStatus: "new-device";
    }>]>>]>;
    readonly "response:get-attestation": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodIntersection<zod.ZodObject<{
        status: zod.ZodLiteral<"success">;
    }, "strip", zod.ZodTypeAny, {
        status: "success";
    }, {
        status: "success";
    }>, zod.ZodObject<{
        attestationDocument: zod.ZodRecord<zod.ZodString, zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        attestationDocument: Record<string, any>;
    }, {
        attestationDocument: Record<string, any>;
    }>>]>;
    readonly "response:complete-onboarding": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodIntersection<zod.ZodObject<{
        status: zod.ZodLiteral<"success">;
    }, "strip", zod.ZodTypeAny, {
        status: "success";
    }, {
        status: "success";
    }>, zod.ZodObject<{
        signerStatus: zod.ZodEnum<["ready"]>;
        publicKeys: zod.ZodRecord<zod.ZodEnum<["secp256k1", "ed25519"]>, zod.ZodObject<Omit<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "keyType">, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }, "strip", zod.ZodTypeAny, {
        signerStatus: "ready";
        publicKeys: Partial<Record<"secp256k1" | "ed25519", {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }, {
        signerStatus: "ready";
        publicKeys: Partial<Record<"secp256k1" | "ed25519", {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }>>]>;
    readonly "response:sign": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodIntersection<zod.ZodObject<{
        status: zod.ZodLiteral<"success">;
    }, "strip", zod.ZodTypeAny, {
        status: "success";
    }, {
        status: "success";
    }>, zod.ZodObject<{
        signature: zod.ZodObject<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>;
        publicKey: zod.ZodObject<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }>;
    }, "strip", zod.ZodTypeAny, {
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
        signature: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        };
    }, {
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
        signature: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        };
    }>>]>;
    readonly "response:get-status": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodIntersection<zod.ZodObject<{
        status: zod.ZodLiteral<"success">;
    }, "strip", zod.ZodTypeAny, {
        status: "success";
    }, {
        status: "success";
    }>, zod.ZodUnion<[zod.ZodObject<{
        signerStatus: zod.ZodEnum<["ready"]>;
        publicKeys: zod.ZodRecord<zod.ZodEnum<["secp256k1", "ed25519"]>, zod.ZodObject<Omit<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "keyType">, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }, "strip", zod.ZodTypeAny, {
        signerStatus: "ready";
        publicKeys: Partial<Record<"secp256k1" | "ed25519", {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }, {
        signerStatus: "ready";
        publicKeys: Partial<Record<"secp256k1" | "ed25519", {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>>;
    }>, zod.ZodObject<{
        signerStatus: zod.ZodEnum<["new-device"]>;
    }, "strip", zod.ZodTypeAny, {
        signerStatus: "new-device";
    }, {
        signerStatus: "new-device";
    }>]>>]>;
}, {
    readonly "request:start-onboarding": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            authId: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            authId: string;
        }, {
            authId: string;
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            authId: string;
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            authId: string;
        };
    }>;
    readonly "request:get-attestation": zod.ZodObject<{
        challenge: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        challenge: string;
    }, {
        challenge: string;
    }>;
    readonly "request:complete-onboarding": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            onboardingAuthentication: zod.ZodObject<{
                encryptedOtp: zod.ZodString;
            }, "strip", zod.ZodTypeAny, {
                encryptedOtp: string;
            }, {
                encryptedOtp: string;
            }>;
        }, "strip", zod.ZodTypeAny, {
            onboardingAuthentication: {
                encryptedOtp: string;
            };
        }, {
            onboardingAuthentication: {
                encryptedOtp: string;
            };
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            onboardingAuthentication: {
                encryptedOtp: string;
            };
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            onboardingAuthentication: {
                encryptedOtp: string;
            };
        };
    }>;
    readonly "request:sign": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }>;
    readonly "request:get-status": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
    }>;
}> | null>;

export { useSignerIFrameWindow };
